==> WWW-OReillyMedia-Store-0.08.tar.gz: WWW-OReillyMedia-Store-0.08/lib/WWW/OReillyMedia/Store.pm <==
package WWW::OReillyMedia::Store;

$WWW::OReillyMedia::Store::VERSION = '0.08';

=head1 NAME

WWW::OReillyMedia::Store - Interface to the OReilly Media Store.

=head1 VERSION

Version 0.08

=cut

use 5.006;
use Data::Dumper;

use XML::Simple;
use LWP::Simple;
use WWW::OReillyMedia::Store::Book;

use Moo;
use namespace::clean;

my $NEW_BOOKS      = "http://feeds.feedburner.com/oreilly/newbooks?format=xml";
my $UPCOMING_BOOKS = "http://feeds.feedburner.com/oreilly/upcomingbooks?format=xml";

has 'new_books_url'      => (is => 'ro', default => sub { return $NEW_BOOKS;      });
has 'upcoming_books_url' => (is => 'ro', default => sub { return $UPCOMING_BOOKS; });

=head1 SYNOPSIS

Objective of this module is to provide an interface to  the  OReilly online media
store. This rely on the RSS feed made public by OReilly.

    use strict; use warnings;
    use WWW::OReillyMedia::Store;

    my $store = WWW::OReillyMedia::Store->new;

    my $new_books      = $store->new_books;
    my $upcoming_books = $store->upcoming_books;

    print $new_books->[0]->as_string();
    print $upcoming_books->[0]->as_string();

=head1 METHODS

=head2 new_books()

Fetches  new books details from OReilly online store realtime. It returns the ref
to a list of objects of type L<WWW::OReillMedia::Store::Book>.

=cut

sub new_books {
    my ($self) = @_;

    return $self->_fetch($self->new_books_url);
}

=head2 upcoming_books()

Fetches upcoming books details from OReilly online store realtime. It returns the
ref to a list of objects of type L<WWW::OReillMedia::Store::Book>.

=cut

sub upcoming_books {
    my ($self) = @_;

    return $self->_fetch($self->upcoming_books_url);
}

sub _fetch {
    my ($url) = @_;

    my $books = [];
    my $xml   = get($url);
    my $feeds = XMLin($xml);
    foreach my $catalog (keys %{$feeds->{entry}}) {
        my $title = $feeds->{entry}->{$catalog}->{title};
        push @$books, WWW::OReillMedia::Store::Book->new({ title => $title, catalog => $catalog });
    }

    return $books;
}

=head1 AUTHOR

Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>

=head1 REPOSITORY

L<https://github.com/Manwar/WWW-OReillyMedia-Store>

=head1 BUGS

Please  report  any  bugs  or feature requests to C<bug-www-oreillymedia-store at
rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-OReillyMedia-Store>.
I will be notified, and then you'll automatically be notified of progress on your
bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc WWW::OReillyMedia::Store

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-OReillyMedia-Store>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/WWW-OReillyMedia-Store>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/WWW-OReillyMedia-Store>

=item * Search CPAN

L<http://search.cpan.org/dist/WWW-OReillyMedia-Store/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2011 - 2014 Mohammad S Anwar.

This  program  is  free software; you can redistribute it and/or modify it under
the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of WWW::OReillyMedia::Store

==> WWW-OReillyMedia-Store-0.09.tar.gz: WWW-OReillyMedia-Store-0.09/lib/WWW/OReillyMedia/Store.pm <==
package WWW::OReillyMedia::Store;

$WWW::OReillyMedia::Store::VERSION = '0.09';

=head1 NAME

WWW::OReillyMedia::Store - Interface to the OReilly Media Store.

=head1 VERSION

Version 0.09

=cut

use 5.006;
use Data::Dumper;

use XML::Simple;
use LWP::Simple;
use WWW::OReillyMedia::Store::Book;

use Moo;
use namespace::clean;

my $NEW_BOOKS      = "http://feeds.feedburner.com/oreilly/newbooks?format=xml";
my $UPCOMING_BOOKS = "http://feeds.feedburner.com/oreilly/upcomingbooks?format=xml";

has 'new_books_url'      => (is => 'ro', default => sub { return $NEW_BOOKS;      });
has 'upcoming_books_url' => (is => 'ro', default => sub { return $UPCOMING_BOOKS; });

=head1 SYNOPSIS

Objective of this module is to provide an interface to  the  OReilly online media
store. This rely on the RSS feed made public by OReilly.

    use strict; use warnings;
    use WWW::OReillyMedia::Store;

    my $store = WWW::OReillyMedia::Store->new;

    my $new_books      = $store->new_books;
    my $upcoming_books = $store->upcoming_books;

    print $new_books->[0]->as_string(), "\n";
    print $upcoming_books->[0]->as_string(), "\n";

=head1 METHODS

=head2 new_books()

Fetches  new books details from OReilly online store realtime. It returns the ref
to a list of objects of type L<WWW::OReillMedia::Store::Book>.

=cut

sub new_books {
    my ($self) = @_;

    return _fetch($self->new_books_url);
}

=head2 upcoming_books()

Fetches upcoming books details from OReilly online store realtime. It returns the
ref to a list of objects of type L<WWW::OReillyMedia::Store::Book>.

=cut

sub upcoming_books {
    my ($self) = @_;

    return _fetch($self->upcoming_books_url);
}

sub _fetch {
    my ($url) = @_;

    my $books = [];
    my $xml   = get($url);
    my $feeds = XMLin($xml);
    foreach my $catalog (keys %{$feeds->{entry}}) {
        my $title = $feeds->{entry}->{$catalog}->{title};
        push @$books, WWW::OReillyMedia::Store::Book->new({ title => $title, catalog => $catalog });
    }

    return $books;
}

=head1 AUTHOR

Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>

=head1 REPOSITORY

L<https://github.com/Manwar/WWW-OReillyMedia-Store>

=head1 BUGS

Please  report  any  bugs  or feature requests to C<bug-www-oreillymedia-store at
rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-OReillyMedia-Store>.
I will be notified, and then you'll automatically be notified of progress on your
bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc WWW::OReillyMedia::Store

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-OReillyMedia-Store>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/WWW-OReillyMedia-Store>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/WWW-OReillyMedia-Store>

=item * Search CPAN

L<http://search.cpan.org/dist/WWW-OReillyMedia-Store/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2011 - 2014 Mohammad S Anwar.

This  program  is  free software; you can redistribute it and/or modify it under
the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of WWW::OReillyMedia::Store
